@@ -102,7 +102,7 @@ class PsmPy:
                 # df_cleaned['propensity_logit'] = np.array(
                 # logit(xi) for xi in pscore)
                 df_cleaned['propensity_logit'] = df_cleaned['propensity_score'].apply(
-                    lambda p: np.log(p/(1-p)))
+                    lambda p: np.log(p/(1-p)) if p < 0.9999 else np.log(p/(0.00001)))
                 appended_data.append(df_cleaned)
             # if some of majority class leftover after the folding for training:
             if majority_len_diff != 0:
@@ -133,7 +133,7 @@ class PsmPy:
                     pscore = logistic.predict_proba(df_cleaned)[:, 1]
                     df_cleaned['propensity_score'] = pscore
                     df_cleaned['propensity_logit'] = df_cleaned['propensity_score'].apply(
-                        lambda p: np.log(p/(1-p)))
+                        lambda p: np.log(p/(1-p)) if p < 0.9999 else np.log(p/(0.00001)))
                     appended_data.append(df_cleaned)
                 else:
                     majority_extra = majority[majority_trunc_len:]
@@ -147,7 +147,7 @@ class PsmPy:
                     pscore = logistic.predict_proba(df_cleaned)[:, 1]
                     df_cleaned['propensity_score'] = pscore
                     df_cleaned['propensity_logit'] = df_cleaned['propensity_score'].apply(
-                        lambda p: np.log(p/(1-p)))
+                        lambda p: np.log(p/(1-p)) if p < 0.9999 else np.log(p/(0.00001)))
                     appended_data.append(df_cleaned)
             else:
                 pass
@@ -196,7 +196,7 @@ class PsmPy:
             pscore = logistic.predict_proba(df_cleaned)[:, 1]
             df_cleaned['propensity_score'] = pscore
             df_cleaned['propensity_logit'] = df_cleaned['propensity_score'].apply(
-                lambda p: np.log(p/(1-p)))
+                lambda p: np.log(p/(1-p)) if p < 0.9999 else np.log(p/(0.00001)))
             predicted_data_reset = df_cleaned.reset_index()
 
             # merge with treatment df
